@@ -9,6 +9,10 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "مایل هستیم به شما اطلاع دهیم که %s تقویم شماره %s را منتشر کرده است.",
     "Open »%s«" : "باز کن »%s«",
     "Cheers!" : "سلامتی!",
+    "Upcoming events" : "رویدادهای پیش‌رو",
+    "Appointments" : "قرارها",
+    "Date:" : "تاریخ:",
+    "Where:" : "مکان:",
     "Calendar" : "تقویم",
     "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
     "Previous day" : "روز قبل",
@@ -76,6 +80,8 @@ OC.L10N.register(
     "Creating subscription …" : "ایجاد اشتراک…",
     "An error occurred, unable to create the calendar." : "خطایی روی داد ، قادر به ایجاد تقویم نیست.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "لطفاً یک پیوند معتبر وارد کنید (با شروع http: // ، https: // ، webcal: // ، یا صفحات وب: //)",
+    "Trash bin" : "زباله‌دان",
+    "Name" : "نام",
     "Import calendars" : "وارد کردن تقویم ها",
     "Please select a calendar to import into …" : "لطفاً یک تقویم را برای وارد کردن به… انتخاب کنید",
     "Filename" : "نام فایل",
@@ -126,6 +132,7 @@ OC.L10N.register(
     "Busy" : "مشغول",
     "Out of office" : "بیرون از دفتر",
     "Unknown" : "نامشخص",
+    "Tentative" : "آزمایشی",
     "Create Talk room for this event" : "اتاق گفتگو را برای این رویداد ایجاد کنید",
     "Show busy times" : " نمایش  زمان‌های  شلوغ",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
@@ -244,7 +251,6 @@ OC.L10N.register(
     "Add a description" : "توضیحات اضافه کنید",
     "Status" : "وضعیت",
     "Confirmed" : "تایید شده",
-    "Tentative" : "آزمایشی",
     "Confirmation about the overall status of the event." : "تأیید درباره وضعیت کلی این رویداد.",
     "Show as" : "نمایش به عنوان",
     "Take this event into account when calculating free-busy information." : "هنگام محاسبه اطلاعات شلوغ رایگان ، این رویداد را در نظر بگیرید.",
@@ -260,19 +266,18 @@ OC.L10N.register(
     "Relaxing" : "آرامش بخش",
     "Relax" : "آروم باش",
     "Presentation" : "ارائه",
-    "Present" : "حاضر",
     "Camping" : "چادر زدن",
     "Camp" : "اردوگاه",
     "Movie" : "فیلم",
     "Cinema" : "سینما",
     "Graduation" : "فارغ التحصیلی",
     "Brainstorm" : "ایده پردازی",
+    "Review" : "مرور",
     "Baseball" : "بیسبال",
     "Meet" : "ملاقات",
     "Planning" : "برنامه ریزی",
     "Pointing" : "اشاره",
     "Retrospective" : "گذشته نگر",
-    "Review" : "مرور",
     "Office" : "دفتر",
     "Contributor week" : "هفته مشارکت کننده",
     "Mail" : "ایمیل",
