@@ -11,6 +11,11 @@ OC.L10N.register(
     "Open »%s«" : "»%s«を開く",
     "Cheers!" : "それでは！",
     "Upcoming events" : "今後のイベント",
+    "Appointments" : "予定",
+    "Appointment:" : "予定：",
+    "Date:" : "日時:",
+    "Where:" : "場所:",
+    "Description:" : "説明:",
     "Calendar" : "カレンダー",
     "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
     "Previous day" : "前日",
@@ -25,7 +30,11 @@ OC.L10N.register(
     "Week" : "週",
     "Month" : "月",
     "List" : "リスト",
+    "Preview" : "プレビュー",
+    "Copy link" : "リンクをコピー",
+    "Edit" : "編集",
     "Delete" : "削除",
+    "Add new" : "新規作成",
     "Untitled calendar" : "無題のカレンダー",
     "Edit name" : "名前を編集",
     "Saving name …" : "名前を保存しています …",
@@ -84,6 +93,9 @@ OC.L10N.register(
     "Deleted" : "削除済み",
     "Restore" : "復元",
     "Delete permanently" : "完全に削除する",
+    "Empty trash bin" : "ゴミ箱を空にする",
+    "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
+    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["ゴミ箱にある項目は {numDays} 日後に削除されます"],
     "Could not update calendar order." : "カレンダーの順番を更新できません。",
     "Import calendars" : "カレンダーのインポート",
     "Please select a calendar to import into …" : "インポートするカレンダーを選択してください …",
@@ -115,8 +127,11 @@ OC.L10N.register(
     "Enable birthday calendar" : "誕生日カレンダーを有効にする",
     "Show tasks in calendar" : "カレンダーにタスクを表示",
     "Enable simplified editor" : "簡易エディターを有効にする",
-    "Show weekends" : "週末を表示",
+    "Limit visible events per view" : "表示するイベントを制限する",
+    "Show weekends" : "週末を表示する",
     "Show week numbers" : "週番号を表示する",
+    "Time increments" : "時間の増加",
+    "Default reminder" : "既定のリマインダー",
     "Copy primary CalDAV address" : "通常のCalDAVアドレスをコピー",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS用のCalDAVアドレスをコピー",
     "Show keyboard shortcuts" : "キーボード ショートカット",
@@ -124,11 +139,24 @@ OC.L10N.register(
     "No reminder" : "リマインダーなし",
     "CalDAV link copied to clipboard." : "CalDAVリンクがクリップボードにコピーされました",
     "CalDAV link could not be copied to clipboard." : "CalDAVリンクをクリップボードにコピーできませんでした",
+    "0 minutes" : "0分",
     "Location" : "場所",
     "Description" : "説明",
+    "Add" : "追加",
     "Monday" : "月曜日",
+    "Tuesday" : "火曜日",
+    "Wednesday" : "水曜日",
+    "Thursday" : "木曜日",
+    "Friday" : "金曜日",
+    "Saturday" : "土曜日",
+    "Sunday" : "日曜日",
+    "Create appointment" : "予定を作成",
+    "Edit appointment" : "予定を編集",
     "Save" : "保存",
     "Update" : "アップデート",
+    "Your name" : "あなたの名前",
+    "Your email address" : "あなたのメールアドレス",
+    "Reminder" : "リマインダー",
     "before at" : "次の時間分早めに通知",
     "Notification" : "通知",
     "Email" : "メール",
@@ -141,6 +169,7 @@ OC.L10N.register(
     "Remove reminder" : "リマインダーを削除",
     "on" : "曜日",
     "+ Add reminder" : "+ リマインダーを追加",
+    "Add reminder" : "リマインダーを追加",
     "_second_::_seconds_" : ["秒"],
     "_minute_::_minutes_" : ["分"],
     "_hour_::_hours_" : ["時間"],
@@ -156,6 +185,7 @@ OC.L10N.register(
     "Busy" : "ビジー",
     "Out of office" : "オフィス外",
     "Unknown" : "不明",
+    "Tentative" : "暫定的",
     "Create Talk room for this event" : "このイベントに通話ルームを作成する",
     "No attendees yet" : "出席者はまだいません",
     "Error creating Talk room" : "通話ルームの作成に失敗しました",
@@ -207,7 +237,9 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} {formattedTime}",
     "Please enter a valid date" : "有効な日付を入力してください",
     "Please enter a valid date and time" : "有効な日付と時刻を入力してください",
+    "Type to search time zone" : "入力して時間帯を検索",
     "Global" : "グローバル",
+    "Select date" : "日付を選択",
     "Personal" : "個人",
     "No more events today" : "今日はこれ以上イベントがありません",
     "No upcoming events" : "今後のイベントはありません",
@@ -233,7 +265,7 @@ OC.L10N.register(
     "Non-working hours" : "休業時間",
     "Not in office" : "欠勤",
     "Phone call" : "電話",
-    "Sick day" : "病欠",
+    "Sick day" : "体調不良",
     "Special occasion" : "特別な用事",
     "Travel" : "旅行",
     "Vacation" : "休暇",
@@ -257,6 +289,9 @@ OC.L10N.register(
     "Untitled event" : "無題のイベント",
     "Untitled task" : "タイトルなしタスク",
     "Please ask your administrator to enable the Tasks App." : "「タスク」アプリを有効化のために、管理者さんにお問い合わせください",
+    "Prev year" : "去年",
+    "Next year" : "来年",
+    "Year" : "年",
     "W" : "W",
     "No events to display" : "表示するイベントはありません",
     "No events" : "イベントはありません",
@@ -267,7 +302,6 @@ OC.L10N.register(
     "Add a description" : "説明を追加",
     "Status" : "ステータス",
     "Confirmed" : "確認済み",
-    "Tentative" : "暫定的",
     "Canceled" : "キャンセル済み",
     "Show as" : "として表示",
     "Categories" : "カテゴリ",
@@ -278,17 +312,26 @@ OC.L10N.register(
     "Meditation" : "座禅",
     "Relaxing" : "休暇",
     "Relax" : "休み",
+    "Finance" : "金融",
+    "Bank" : "銀行",
+    "Money" : "お金",
+    "Wedding" : "結婚式",
+    "Dog" : "犬",
+    "Concert" : "演奏会",
+    "Festival" : "祭",
     "Presentation" : "プレゼンテーション",
-    "Present" : "プレゼン",
     "Camping" : "キャンプ場",
     "Camp" : "キャンプ",
+    "Election" : "選挙",
+    "Voting" : "投票",
+    "Vote" : "投票",
     "Movie" : "ムービー",
     "Cinema" : "映画館",
     "Graduation" : "卒業式",
     "Brainstorm" : "会議",
+    "Review" : "レビュー",
     "Baseball" : "野球",
     "Meet" : "打ち合わせ",
-    "Review" : "レビュー",
     "Office" : "オフィス",
     "Mail" : "メール",
     "Soccer" : "サッカー",
@@ -297,6 +340,7 @@ OC.L10N.register(
     "Drive" : "ドライブ",
     "Bicycle" : "自転車",
     "Cycle" : "自転車",
+    "Cycling" : "サイクリング",
     "Biking" : "サイクリング",
     "Podcast" : "生放送",
     "Basketball" : "バスケットボール",
@@ -308,10 +352,12 @@ OC.L10N.register(
     "Museum" : "美術館",
     "Pilates" : "ピラティス",
     "Park" : "公園",
+    "Walk" : "散歩",
     "Studying" : "勉強",
     "Doctor" : "病院",
     "Health" : "診断",
     "Dentist" : "歯医者",
+    "Hospital" : "病院",
     "Interview" : "インタビュー",
     "Training" : "トレーニング",
     "Sports" : "スポーツ",
@@ -340,21 +386,26 @@ OC.L10N.register(
     "Conference" : "カンファレンス",
     "Pizza" : "ピザ",
     "Travelling" : "旅行",
+    "Trip" : "旅行",
     "Journey" : "旅",
     "Collaborate" : "一緒",
     "Pair" : "ペア",
     "Lecture" : "講義",
     "Seminar" : "ゼミ",
+    "Teaching" : "授業",
     "Photograph" : "写真",
     "Party" : "パーティー",
     "Celebration" : "祝",
     "Celebrate" : "お祝い",
+    "Birthday" : "誕生日",
     "Shopping" : "買い物",
     "Skate" : "スケート",
     "Skateboard" : "スケートボード",
     "Wine tasting" : "ワイン",
     "Golf" : "ゴルフ",
     "Dinner" : "ディナー",
-    "Lunch" : "ランチ"
+    "Lunch" : "ランチ",
+    "Appointment not found" : "予定が見つかりません",
+    "User not found" : "ユーザーが見つかりません"
 },
 "nplurals=1; plural=0;");
