@@ -11,6 +11,19 @@ OC.L10N.register(
     "Open »%s«" : "Accesează »%s«",
     "Cheers!" : "Noroc!",
     "Upcoming events" : "Evenimente viitoare",
+    "Appointments" : "Întâlniri",
+    "Schedule appointment \"%s\"" : "Planifică programarea \"%s\"",
+    "Schedule an appointment" : "Planifică o programare",
+    "Prepare for %s" : "Pregăteste-te de %s",
+    "Your appointment \"%s\" needs confirmation" : "Programarea \"%s\" necesită confirmare",
+    "Dear %s, please confirm your booking" : "Dragă %s, te rog să confirmi rezervarea ta",
+    "Confirm" : "Confirmă",
+    "This confirmation link expires in %s hours." : "Acest link de confirmare expira în %s ore. ",
+    "If you wish to cancel the appointment after all, please contact your organizer." : "Dacă dorești să anulezi programarea, te rugăm să contactezi organizatorul.",
+    "Appointment:" : "Programare:",
+    "Date:" : "Data:",
+    "Where:" : "Unde:",
+    "Description:" : "Descriere:",
     "Calendar" : "Calendar",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
@@ -25,7 +38,13 @@ OC.L10N.register(
     "Week" : "Săptămâna",
     "Month" : "Luna",
     "List" : "Listă",
+    "Preview" : "Previzualizare",
+    "Copy link" : "Copiază link",
+    "Edit" : "Editează",
     "Delete" : "Șterge",
+    "Appointment link was copied to clipboard" : "Linkul programării a fost copiat în clipboard",
+    "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
+    "Add new" : "Adaugă nou",
     "Untitled calendar" : "Calendar nedenumit",
     "Edit name" : "Modifică numele",
     "Saving name …" : "Se salvează numele ...",
@@ -41,6 +60,7 @@ OC.L10N.register(
     "An error occurred, unable to rename the calendar." : "A apărut o eroare, acest calendar nu se poate redenumi.",
     "An error occurred, unable to change the calendar's color." : "A apărut o eroare, nu se poate schimba culoarea calendarului.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Se șterge calendarul în {countdown} secundă","Se șterge calendarul în {countdown} secunde","Se șterge calendarul în {countdown} de secunde"],
     "Share link" : "Partajază legătură",
     "Publish calendar" : "Publică calendarul",
     "Publishing calendar" : "Se publică calendarul",
@@ -48,6 +68,9 @@ OC.L10N.register(
     "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
     "Enter one address" : "Introdu o adresă",
     "Sending email …" : "Email-ul se trimite ...",
+    "Copy subscription link" : "Copiază linkul abonamentului",
+    "Copying link …" : "Copiază link ...",
+    "Copied link" : "Link copiat",
     "Could not copy link" : "Nu s-a putut copia link-ul",
     "Copy embedding code" : "Copiați codul de încorporare",
     "Copying code …" : "Se copiază codul ...",
@@ -125,16 +148,52 @@ OC.L10N.register(
     "Default reminder" : "Memento implicit",
     "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
     "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
+    "Personal availability settings" : "Setări de disponibilitate",
     "Show keyboard shortcuts" : "Arată scurtături",
     "Settings & import" : "Setări și import",
     "No reminder" : "Fără mementouri",
     "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
     "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
+    "Appointment was created successfully" : "Programarea a fost creeata cu succes",
+    "Appointment was updated successfully" : "Programarea a fost actualizată cu succes",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
+    "0 minutes" : "0 minute",
+    "To configure appointments, add your email address in personal settings." : "Pentru a configura programările, adăugați-vă adresa email în setările personale.",
+    "Public – shown on the profile page" : "Public- arată pepagina de profil",
+    "Private – only accessible via secret link" : "Private - accesibil doar prin folosirea unui link secret",
     "Location" : "Locație",
     "Description" : "Descriere",
+    "Visibility" : "Vizibil",
+    "Duration" : "Durată",
+    "Increments" : "Incremente",
+    "Additional calendars to check for conflicts" : "Calendarele adiționale să fie verificate pentru conflicte ",
+    "Pick time ranges where appointments are allowed" : "Alege intervale de timp în cadrul cărora programările sunt permise",
+    "to" : "către",
+    "Delete slot" : "Șterge slotul",
+    "No times set" : "Nici-un timp setat",
+    "Add" : "Adaugă",
     "Monday" : "Luni",
+    "Tuesday" : "Marți",
+    "Wednesday" : "Miercuri",
+    "Thursday" : "Joi",
+    "Friday" : "Vineri",
+    "Saturday" : "Sâmbătă",
+    "Sunday" : "Duminică",
+    "Add time before and after the event" : "Adaugă un interval de timp înainte și după eveniment",
+    "Before the event" : "Înainte și după",
+    "After the event" : "După eveniment",
+    "Planning restrictions" : "Planifică retricții",
+    "Minimum time before next available slot" : "Timpul minim înaintea următorului slot de timp disponibil",
+    "Max slots per day" : "Numărul de sloturi pe zi",
+    "Create appointment" : "Creează programare",
+    "Edit appointment" : "Editează programarea",
     "Save" : "Salvează",
     "Update" : "Actualizare",
+    "Your appointment is booked" : "Rezervarea ta este confirmată",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ți-am trimis un email cu detalii. Te rugăm să confirmi programarea ta folosind linkul din email. Poți închide această pagină acum.",
+    "Your name" : "Numele tău",
+    "Your email address" : "Adresa ta de email",
+    "Please share anything that will help prepare for our meeting" : "Te rugăm să împărtășești orice informație ce ne poate ajuta în pregătirea pentru ședința noastră.",
     "Reminder" : "Memento",
     "before at" : "Înainte de la",
     "Notification" : "Notificări",
@@ -167,11 +226,14 @@ OC.L10N.register(
     "Participation marked as tentative." : "Participarea a fost marcată ca o încercare.",
     "Invitation sent." : "Invitaţia a fost trimisă.",
     "Unknown" : "Necunoscut",
+    "Tentative" : "Tentativă",
     "Repeat" : "Repetă",
     "never" : "niciodată",
     "after" : "după",
     "More" : "Mai mult",
     "Global" : "Global",
+    "Time:" : "Timp:",
+    "Booked for:" : "Rezervat pentru:",
     "Personal" : "Personal",
     "Details" : "Detalii",
     "Attendees" : "Participanți",
@@ -180,12 +242,23 @@ OC.L10N.register(
     "Week {number} of {year}" : "Săptămâna {number} din {year}",
     "Daily" : "Zilnic",
     "Weekly" : "Săptămânal",
+    "Untitled event" : "Eveniment fără titlu",
+    "Untitled task" : "Sarcină fără titlu",
+    "Prev" : "Precedent",
+    "Next" : "Următorul",
+    "Prev year" : "Anul anterior",
+    "Next year" : "Aanul viitor",
+    "Year" : "An",
+    "W" : "W",
+    "%n more" : "%n mai mult",
+    "No events to display" : "Nu sunt evenimente de afișat",
+    "No events" : "Niciun eveniment",
+    "Meeting room" : "Sală de ședințe",
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
     "Status" : "Stare",
     "Confirmed" : "Confirmat",
-    "Tentative" : "Tentativă",
     "Mail" : "Mail"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
